==> rc-ui-lib-0.1.59.tgz: package/lib/config-provider/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

function _react() {
  var data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _icon = _interopRequireDefault(require("../../icon"));

var _ = _interopRequireDefault(require(".."));

describe('ConfigProvider', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('when using themeVars prop', function () {
    var themeVars = {
      color: 'red'
    };
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, {
      themeVars: themeVars
    }, /*#__PURE__*/_react().default.createElement(_icon.default, {
      name: "success"
    })));
    expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();
  });
  it('when using iconPrefix prop', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, {
      iconPrefix: "my-icon"
    }, /*#__PURE__*/_react().default.createElement(_icon.default, {
      name: "success"
    })));
    expect(wrapper.find('i.my-icon-success').exists()).toBeTruthy();
  });
});

==> rc-ui-lib-0.2.4.tgz: package/lib/config-provider/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

function _react() {
  var data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _icon = _interopRequireDefault(require("../../icon"));

var _ = _interopRequireDefault(require(".."));

describe('ConfigProvider', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('when using themeVars prop', function () {
    var themeVars = {
      color: 'red'
    };
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, {
      themeVars: themeVars
    }, /*#__PURE__*/_react().default.createElement(_icon.default, {
      name: "success"
    })));
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('when using iconPrefix prop', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, {
      iconPrefix: "my-icon"
    }, /*#__PURE__*/_react().default.createElement(_icon.default, {
      name: "success"
    })));
    expect(wrapper.find('i.my-icon-success').exists()).toBeTruthy();
  });
});
